package com.pokkt.demo.fragments;

import android.content.Context;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.Toast;

import com.pokkt.PokktAds;
import com.pokkt.ad.demo.R;
import com.pokkt.demo.utility.SharedPrefsUtil;

import static com.pokkt.demo.utility.SharedPrefsUtilConstant.*;

import com.pokkt.sdk.models.PokktAdPlayerViewConfig;

import java.util.Map;


public class PokktExtraParamsFragment extends BaseFragment {

    // ui
    private Button btnAddExtraParams, btnRemoveExtraParams, btnSend;
    private LinearLayout lnrLayoutExtraParamsContainer;

    private LayoutInflater inflater;

    PokktAdPlayerViewConfig config = new PokktAdPlayerViewConfig();

    public PokktExtraParamsFragment() {
        // Required empty public constructor
    }


    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        // getArguments here
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.fragment_pokkt_extra_params, container, false);
        btnAddExtraParams = (Button) rootView.findViewById(R.id.btnAddExtraParams);
        btnRemoveExtraParams = (Button) rootView.findViewById(R.id.btnRemoveExtraParams);
        btnSend = (Button) rootView.findViewById(R.id.btnSend);
        lnrLayoutExtraParamsContainer = (LinearLayout) rootView.findViewById(R.id.lnrLayoutExtraParamsContainer);
        this.inflater = inflater;
        btnAddExtraParams.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                addRow();
            }
        });
        btnRemoveExtraParams.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                resetData();
            }
        });
        btnSend.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {

                saveData();
                Map<String, String> map_extra_params = (Map<String, String>) SharedPrefsUtil.getMapFromPref(getActivity().getApplicationContext(), PREF_EXTRA_PARAMS);

                if(map_extra_params.size() > 0){
                    PokktAds.setCallbackExtraParams(map_extra_params);
                }
                else{
                    Toast.makeText(getActivity().getApplicationContext(), "Add extra params to be sent to PokktSDK", Toast.LENGTH_SHORT).show();
                }
            }
        });

        return rootView;
    }

    @Override
    public void onViewCreated(View view, Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);

        setFont(findView(view, R.id.txt_ad_settings));
        setFont(findView(view, R.id.btnAddExtraParams));
        setFont(findView(view, R.id.btnRemoveExtraParams));
        // setup data
        try {
            bindData();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private EditText[] addRow() {
        View child = inflater.inflate(R.layout.layout_extra_params_row, null);
        EditText edtKey = (EditText) child.findViewById(R.id.edtKey);
        EditText edtValue = (EditText) child.findViewById(R.id.edtValue);
        setFont(edtKey);
        setFont(edtValue);
        lnrLayoutExtraParamsContainer.addView(child);
        return new EditText[]{edtKey, edtValue};
    }

    private void setRowData(String key, String value) {

        EditText[] addedChildren = addRow();
        addedChildren[0].setText(key);
        addedChildren[1].setText(value);
    }

    private void bindData() throws Exception {

        Map<String, String> map_extra_params = (Map<String, String>) SharedPrefsUtil.getMapFromPref(getActivity().getApplicationContext(), PREF_EXTRA_PARAMS);
        if (map_extra_params.size() > 0) {
            for (Map.Entry<String, String> pair : map_extra_params.entrySet()) {
                SharedPrefsUtil.getStringPref(getActivity().getApplicationContext(),
                        PREF_EXTRA_PARAMS, pair.getKey());
                setRowData(pair.getKey(), pair.getValue());
            }
        }
    }

    private void resetData(){
        SharedPrefsUtil.clearSharedPref(getActivity().getApplicationContext(), PREF_EXTRA_PARAMS);
        lnrLayoutExtraParamsContainer.removeAllViews();
    }

    @Override
    public void onDestroy() {
        saveData();
        super.onDestroy();
    }

    private void saveData(){
        SharedPrefsUtil.clearSharedPref(getActivity().getApplicationContext(), PREF_EXTRA_PARAMS);

        for (int i = 0; i < lnrLayoutExtraParamsContainer.getChildCount(); i++) {

            View child = lnrLayoutExtraParamsContainer.getChildAt(i);
            EditText edtKey = (EditText) child.findViewById(R.id.edtKey);
            EditText edtValue = (EditText) child.findViewById(R.id.edtValue);

            if (!TextUtils.isEmpty(edtKey.getText().toString())) {
                SharedPrefsUtil.setStringPref(getActivity().getApplicationContext(), PREF_EXTRA_PARAMS, edtKey.getText().toString(), edtValue.getText().toString());
            }
        }
    }
}
